@@ -3,7 +3,7 @@ use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '1.56';
+our $VERSION = '1.58';
 
 use Carp;
 use Data::Compare;
@@ -219,6 +219,12 @@ sub remove {
 
     $self->run($p);
 }
+sub order {
+    trace() if $ENV{TRACE};
+
+    my $self = shift;
+    return @{ $self->{order} };
+}
 
 #
 # publicly available semi-private developer methods
@@ -493,9 +499,10 @@ sub _clean_core_config {
 
     my $self = shift;
 
-    # clean params that we collected after _clean_config()
+    # delete params we collected after _clean_config()
 
     delete $self->{params}{file_contents};
+    delete $self->{params}{order};
 
     my @core_phases = qw(
         pre_proc
@@ -563,6 +570,7 @@ sub _config {
         line_num => 0,              # inject()
         add_functionality => 0,
         add_functionality_prod => 0,
+        order => 0,
     );
 
     $self->{valid_params} = \%valid_params;
@@ -678,7 +686,10 @@ sub _params {
     return \%params;
 }
 sub _read_file {
-    
+
+    # this sub prepares a temp copy of the original file,
+    # recseps changed to local platform for PPI
+
     trace() if $ENV{TRACE};
 
     my $self = shift;
@@ -696,12 +707,30 @@ sub _read_file {
 
     $self->{rw} = File::Edit::Portable->new;
 
-    my @file_contents
-      = $self->{rw}->read(file => $file);
+    my $fh = $self->{rw}->read($file);
+    my $tempfile = $self->{rw}->tempfile;
+    my $tempfile_name = $tempfile->filename;
+    my $platform_recsep = $self->{rw}->platform_recsep;
 
-    @{ $p->{file_contents} } = @file_contents;
+    $self->{rw}->write(
+        copy => $tempfile_name, 
+        contents => $fh, 
+        recsep => $platform_recsep
+    );
 
-    return @file_contents;
+    my $ppi_doc = PPI::Document->new($tempfile_name);
+    
+    @{ $p->{file_contents} } = split /\n/, $ppi_doc->content;
+
+    close $tempfile;
+
+    if (! $p->{file_contents}->[0]){
+        return 0;
+    }
+    else {
+        $self->{params}{file_contents} = $p->{file_contents};
+        return 1;
+    }
 }
 sub _run_directory {
     
@@ -762,7 +791,7 @@ sub _write_file {
     
     my $file = $self->{params}{file};
     my $contents = $self->{write_file_contents};
-   
+
     return if ! $file;
     $file = $copy if $copy;
 
@@ -836,9 +865,9 @@ sub _core {
         $subs = $self->_cache($p->{file});
     }
     else {
-        $subs = $self->_proc;
+        $subs = $self->_proc($p);
     } 
-  
+
     return if ! $subs;
 
     # write to cache
@@ -952,25 +981,23 @@ sub _proc {
     trace() if $ENV{TRACE};
     
     my $self = shift;
-    
+    my $p = shift;
+   
     my $file = $self->{params}{file};
 
     return {} if ! $file;
 
-    my $PPI_doc = PPI::Document->new($file);
-    my $PPIsubs = $PPI_doc->find("PPI::Statement::Sub");
+    my $PPI_doc = PPI::Document->new($file);   
+    my $PPI_subs = $PPI_doc->find('PPI::Statement::Sub');
 
-    return if ! $PPIsubs;
-
-    my @file_contents = @{ $self->{params}{file_contents} };
+    return if ! $PPI_subs;
 
     my %subs;
     $subs{$file} = {};
-    
-    @{$subs{$file}{contents}} = @file_contents;
-
-    for my $PPI_sub (@{$PPIsubs}){
+    my @sub_order;
 
+    for my $PPI_sub (@{$PPI_subs}){
+        
         my $include 
           = defined $self->{params}{include} ? $self->{params}{include} : [];
         my $exclude
@@ -979,6 +1006,8 @@ sub _proc {
         delete $self->{params}{include} if $exclude->[0];
 
         my $name = $PPI_sub->name;
+        
+        push @sub_order, $name;
 
         # skip over excluded (or not included) subs
 
@@ -1004,18 +1033,12 @@ sub _proc {
 
         $subs{$file}{subs}{$name}{num_lines} = $sub_line_count;
 
-        # pull out just the subroutine from the file 
-        # array and attach it to the structure
-
-        my @sub_definition = @file_contents[
-                                    $subs{$file}{subs}{$name}{start}
-                                    ..
-                                    $subs{$file}{subs}{$name}{end}
-                                   ];
-
-        $subs{$file}{subs}{$name}{contents} = \@sub_definition;
+        @{ $subs{$file}{subs}{$name}{code} } = split /\n/, $PPI_sub->content;
     }
-   
+  
+    @{ $p->{order} } = @sub_order; 
+    @{ $self->{order} } = @sub_order;
+
     return \%subs;
 }
 sub _post_proc {
@@ -1321,7 +1344,7 @@ Note: omit the C<file> parameter if all you'll be using is the C<module()> metho
 Mandatory parameters: None
 
 Returns an array reference containing the names of all subroutines found in
-the file.
+the file, listed in the order they appear in the file.
 
 
 
@@ -1386,6 +1409,10 @@ module's namespace symbol table.
 
 
 
+=head2 C<order>
+
+After one of the other user methods are called, call this method to get returned to you an array of
+the names of subs you collected, in the order that they appear in the file. By default, because we use hashes internally, subs aren't ever in proper order.
 
 
 
@@ -1827,6 +1854,12 @@ will be executed based on their order in the array reference.
 
 =head1 REPOSITORY
 
+=begin html
+ 
+<a href="http://travis-ci.org/stevieb9/devel-examine-subs"><img src="https://secure.travis-ci.org/stevieb9/devel-examine-subs.png"/></a> <a href="https://coveralls.io/r/stevieb9/devel-examine-subs"><img src="https://coveralls.io/repos/stevieb9/devel-examine-subs.png?branch=master"/></a>
+ 
+=end html
+
 L<https://github.com/stevieb9/devel-examine-subs>
 
 =head1 BUILD REPORTS
