@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.56';
+our $VERSION = '1.58';
 
 use Carp;
 use Data::Dumper;
@@ -105,7 +105,11 @@ sub all {
 
         my $file = $p->{file};
 
-        my @subs = keys %{$struct->{$file}{subs}};
+        my @subs;
+
+        for my $name (@{ $p->{order} }){
+            push @subs, grep {$name eq $_} keys %{ $struct->{$file}{subs} };
+        } 
 
         return \@subs;
     };
@@ -154,7 +158,7 @@ sub missing {
 
         for my $file (keys %$struct){
             for my $sub (keys %{$struct->{$file}{subs}}){
-                my @code = @{$struct->{$file}{subs}{$sub}{contents}};
+                my @code = @{$struct->{$file}{subs}{$sub}{code}};
 
                 my @clean;
 
@@ -186,7 +190,7 @@ sub lines {
         for my $file (keys %$struct){
             for my $sub (keys %{$struct->{$file}{subs}}){
                 my $line_num = $struct->{$file}{subs}{$sub}{start};
-                my @code = @{$struct->{$file}{subs}{$sub}{contents}};
+                my @code = @{$struct->{$file}{subs}{$sub}{code}};
                 for my $line (@code){
                     $line_num++;
                     push @{$return{$sub}}, {$line_num => $line};
