@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.56';
+our $VERSION = '1.58';
 
 use Carp;
 use Data::Dumper;
@@ -97,7 +97,7 @@ sub subs {
                 $s->{$f}{subs}{$sub}{start}++;
                 $s->{$f}{subs}{$sub}{end}++;
                 $s->{$f}{subs}{$sub}{name} = $sub;
-                @{ $s->{$f}{subs}{$sub}{file} } = @{ $s->{$f}{contents} };
+                @{ $s->{$f}{subs}{$sub}{code} } = @{ $s->{$f}{subs}{$sub}{code} };
                 push @subs, $s->{$f}{subs}{$sub};
             }
         }
@@ -131,7 +131,7 @@ sub file_lines_contain {
             for my $sub (keys %{$s->{$f}{subs}}){
                 my $found = 0;
                 my @has;
-                for (@{$s->{$f}{subs}{$sub}{contents}}){
+                for (@{$s->{$f}{subs}{$sub}{code}}){
                     if ($_ and /$search/){
                         $found++;
                         push @has, $_;
@@ -141,7 +141,7 @@ sub file_lines_contain {
                     delete $s->{$f}{subs}{$sub};                
                     next;
                 }
-                $s->{$f}{subs}{$sub}{contents} = \@has;
+                $s->{$f}{subs}{$sub}{code} = \@has;
             }
         }
         return $struct;
