@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.56';
+our $VERSION = '1.58';
 
 use Data::Dumper;
 
@@ -90,7 +90,7 @@ sub code {
 
     my $self = shift;
 
-    my $code = $self->{data}{contents};
+    my $code = $self->{data}{code};
 
     return $code;
 }
